Documentation
¶
Index ¶
Constants ¶
const ( // Default number of journeys to return when not specified DefaultJourneysPerPage = 25 // Maximum number of journeys to return per page MaxJourneysPerPage = 100 )
const ( // Default number of sessions to return when not specified DefaultSessionsPerPage = 25 // Maximum number of sessions to return per page MaxSessionsPerPage = 100 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ListJourneyConfig ¶ added in v0.2.0
type ListJourneyConfig struct {
// The number of Journeys to return per page
JourneysPerPage int
// The list of platforms to match. If none are specified, all platforms will be returned
Platforms []commonProto.DevicePlatform
// The start time to match
Since time.Time
// The end time to match
Until time.Time
}
ListJourneyConfig allows for setting the criteria to be used when requesting a list of journeys.
type ListSessionConfig ¶
type ListSessionConfig struct {
// The number of Sessions to return per page
SessionsPerPage int
// A list of Labels to match
Labels []string
// The journey id to match
JourneyId string
// The list of platforms to match. If none are specified, all platforms will be returned
Platforms []commonProto.DevicePlatform
// The start time to match
Since time.Time
// The end time to match
Until time.Time
}
ListSessionConfig allows for setting the criteria to be used when requesting a list of sessions.
type SDKConfig ¶
type SDKConfig struct {
// API secret token generated from the Moonsense Cloud web console
SecretToken string
// Root API domain (defaults to moonsense.cloud)
RootDomain string
// Protocol to use when connecting to the API (defaults to https)
Protocol string
// Default Moonsense Cloud Data Plane region to connect to
DefaultRegion string
}
SDKConfig is used to configure the SDK for accessing the Moonsense Cloud.
Click to show internal directories.
Click to hide internal directories.